#ifndef LIBGUILEH
#define LIBGUILEH

/*	Copyright (C) 1995, 1996, 1997, 1998, 2000, 2001 Free Software Foundation, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307 USA
 *
 * As a special exception, the Free Software Foundation gives permission
 * for additional uses of the text contained in its release of GUILE.
 *
 * The exception is that, if you link the GUILE library with other files
 * to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the GUILE library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the
 * Free Software Foundation under the name GUILE.  If you copy
 * code from other Free Software Foundation releases into a copy of
 * GUILE, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for GUILE, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.  */


#ifdef __cplusplus
extern "C" {
#endif

#include "libguile16/__scm.h"

/* These files define typedefs used by later files, so they need to
   come first.  */
#include "libguile16/print.h"
#include "libguile16/smob.h"
#include "libguile16/pairs.h"

#include "libguile16/alist.h"
#include "libguile16/arbiters.h"
#include "libguile16/async.h"
#include "libguile16/boolean.h"
#include "libguile16/chars.h"
#include "libguile16/continuations.h"
#ifdef DEBUG_EXTENSIONS
#include "libguile16/backtrace.h"
#include "libguile16/debug.h"
#include "libguile16/stacks.h"
#endif
#include "libguile16/dynl.h"
#include "libguile16/dynwind.h"
#include "libguile16/eq.h"
#include "libguile16/error.h"
#include "libguile16/eval.h"
#include "libguile16/evalext.h"
#include "libguile16/feature.h"
#include "libguile16/filesys.h"
#include "libguile16/fluids.h"
#include "libguile16/fports.h"
#include "libguile16/gc.h"
#include "libguile16/gdbint.h"
#include "libguile16/goops.h"
#include "libguile16/gsubr.h"
#include "libguile16/guardians.h"
#include "libguile16/hash.h"
#include "libguile16/hashtab.h"
#include "libguile16/init.h"
#include "libguile16/ioext.h"
#include "libguile16/rdelim.h"
#include "libguile16/rw.h"
#include "libguile16/keywords.h"
#include "libguile16/list.h"
#include "libguile16/load.h"
#include "libguile16/macros.h"
#include "libguile16/mallocs.h"
#include "libguile16/modules.h"
#include "libguile16/net_db.h"
#include "libguile16/numbers.h"
#include "libguile16/objects.h"
#include "libguile16/objprop.h"
#include "libguile16/options.h"
#include "libguile16/ports.h"
#include "libguile16/posix.h"
#include "libguile16/procprop.h"
#include "libguile16/properties.h"
#include "libguile16/procs.h"
#include "libguile16/ramap.h"
#include "libguile16/random.h"
#include "libguile16/read.h"
#include "libguile16/root.h"
#include "libguile16/scmsigs.h"
#include "libguile16/script.h"
#include "libguile16/simpos.h"
#include "libguile16/snarf.h"
#include "libguile16/socket.h"
#include "libguile16/sort.h"
#include "libguile16/srcprop.h"
#include "libguile16/stackchk.h"
#include "libguile16/stime.h"
#include "libguile16/strings.h"
#include "libguile16/strop.h"
#include "libguile16/strorder.h"
#include "libguile16/strports.h"
#include "libguile16/struct.h"
#include "libguile16/symbols.h"
#include "libguile16/tags.h"
#include "libguile16/throw.h"
#include "libguile16/unif.h"
#include "libguile16/validate.h"
#include "libguile16/values.h"
#include "libguile16/variable.h"
#include "libguile16/vectors.h"
#include "libguile16/version.h"
#include "libguile16/vports.h"
#include "libguile16/weaks.h"
#ifdef USE_THREADS
#include "libguile16/threads.h"
#endif

/* Deprecated type names.  Don't use them for new code. */

#if SCM_DEBUG_DEPRECATED == 0

typedef scm_t_array_dim scm_array_dim_t;
typedef scm_t_array scm_array_t;
typedef scm_t_bits scm_bits_t;
typedef scm_t_c_bvec_limb scm_c_bvec_limb_t;
typedef scm_t_c_hook_entry scm_c_hook_entry_t;
typedef scm_t_c_hook_function scm_c_hook_function_t;
typedef scm_t_c_hook scm_c_hook_t;
typedef scm_t_catch_body scm_catch_body_t;
typedef scm_t_catch_handler scm_catch_handler_t;
typedef scm_t_complex scm_complex_t;
typedef scm_t_contregs scm_contregs_t;
typedef scm_t_debug_frame scm_debug_frame_t;
typedef scm_t_debug_info scm_debug_info_t;
typedef scm_t_double scm_double_t;
typedef scm_t_fport scm_fport_t;
typedef scm_t_guard scm_guard_t;
typedef scm_t_i_rstate scm_i_rstate_t;
typedef scm_t_info_frame scm_info_frame_t;
typedef scm_t_inner scm_inner_t;
typedef scm_t_method scm_method_t;
typedef scm_t_option scm_option_t;
typedef scm_t_port_rw_active scm_port_rw_active_t;
typedef scm_t_port scm_port_t;
typedef scm_t_ptob_descriptor scm_ptob_descriptor_t;
typedef scm_t_rng scm_rng_t;
typedef scm_t_rstate scm_rstate_t;
typedef scm_t_signed_bits scm_signed_bits_t;
typedef scm_t_srcprops_chunk scm_srcprops_chunk_t;
typedef scm_t_srcprops scm_srcprops_t;
typedef scm_t_stack scm_stack_t;
typedef scm_t_struct_free scm_struct_free_t;
typedef scm_t_subr_entry scm_subr_entry_t;

#ifdef USE_THREADS

typedef scm_t_cond scm_cond_t;
typedef scm_t_key scm_key_t;
typedef scm_t_mutex scm_mutex_t;

#endif

#endif /* !SCM_DEBUG_DEPRECATED */

#ifdef __cplusplus
}
#endif



#endif  /* LIBGUILEH */

/*
  Local Variables:
  c-file-style: "gnu"
  End:
*/
